# Foobar

Foobar is a Python library for dealing with word pluralization.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install converter-package==0.4
```

## Usage
Interface.py is an example of usage, it is available on the ACCORDION's Gitlab


## License
[MIT](https://choosealicense.com/licenses/mit/)